#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : demo
# @Time         : 2020/10/26 2:58 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 



语文 = float(input("语文："))
数学 = float(input("数学："))
英语 = float(input("英语："))

print(0.5 * 语文 + 0.3 * 数学 + 0.2 * 英语)
